@@ -20,7 +20,7 @@
 #' @return A tibble with the individuals' responses to the questionnaire retrieved.
 #' @examples
 #'\dontrun{
-#' Get the merged barometer from 2014, by default (assume kind = "barometer").
+#' # Get the merged barometer from 2014, by default (assume kind = "barometer").
 #' d <- CEOdata()
 #'
 #' # Get the number of individuals surveyed and the number of variables recorded.
@@ -29,7 +29,7 @@
 #' # Get the identifiers of the different Barometers retrieved
 #' unique(d$BOP_NUM)
 #'
-#' Get a specific study
+#' # Get a specific study
 #' d746 <- CEOdata(reo = "746")
 #'}
 CEOdata <- function(kind = "barometer",
@@ -44,7 +44,7 @@ CEOdata <- function(kind = "barometer",
     url.phone.barometer <- "https://ceo.gencat.cat/web/.content/20_barometre/Matrius_BOP/2013_Microdades_anonimitzades_fusio_cine_telf.zip"
     file.phone.barometer.rar <- "2013_Microdades_anonimitzades_fusio_cine_telf.zip"
     file.phone.barometer <- "Microdades anonimitzades fusio cine telf.sav"
-    url.presential.barometer <- "https://ceo.gencat.cat/web/.content/20_barometre/Matrius_BOP/Microdades_Des20.zip.zip"
+    url.presential.barometer <- "https://ceo.gencat.cat/web/.content/20_barometre/Matrius_BOP/Microdades_barometre.zip"
     file.presential.barometer <- "Microdades anonimitzada fusio presencial.sav"
     # Process barometer merged from 2014
     if (kind == "barometer") {
@@ -138,8 +138,35 @@ CEOdata <- function(kind = "barometer",
       if (length(reo) == 1) {
         url.reo <- CEOmetadata()$`Enllac matriu de dades`[CEOmetadata()$REO == reo]
         if (!is.na(url.reo)) {
-          try({d <- haven::read_spss(url.reo)}, silent = TRUE)
-          if (!exists(quote(d))) {
+          tmp <- tempfile()
+          try({download.value <- download.file(url.reo, tmp)}, silent = TRUE)
+          if (exists(quote(download.value))) {
+            if (download.value == 0) { # success downloading the file
+              files.within <- unzip(tmp, list = TRUE)
+              if (dim(files.within)[1] == 1) {
+                if (!stringr::str_detect(files.within$Name, "\\.sav$")) {
+                  warning("This zip file does not contain a .sav file")
+                  return(NULL)
+                } else {
+                  file <- unzip(tmp, files.within$Name)
+                  message("Converting the original data into R. This may take a while.")
+                  try({d <- haven::read_spss(file)}, silent = TRUE)
+                  if (!exists(quote(d))) {
+                    warning("The .sav file can't be processed.")
+                    return(NULL)
+                  } else {
+                    return(d)
+                  }
+                  if (file.exists(file)) {
+                    unlink(file)
+                  }
+                }
+              } else {
+                warning("The zip file does not contain one, and only one, single file")
+                return(NULL)
+              }
+            }
+          } else {
             message("A problem downloading the specific barometer file has occurred. The server may be temporarily down, or the file name has changed. Please try again later or open an issue at https://github.com/ceopinio/CEOdata indicating 'Problem with barometer'")
             return(NULL)
           }
